@@ -1,6 +1,6 @@
 """Initialize the package."""
 from pystibmivb.client import AbstractSTIBAPIClient, STIBAPIClient
-from pystibmivb.service import STIBService, InvalidLineFilterException
+from pystibmivb.service import STIBService, InvalidLineFilterException, NoScheduleFromAPIException
 from pystibmivb.service import ShapefileService
 from .domain import *
 
