@@ -1,4 +1,3 @@
-import json
 import logging
 import datetime
 
@@ -8,8 +7,7 @@ from pystibmivb.service.ShapefileService import ShapefileService
 
 LOGGER = logging.getLogger(__name__)
 
-LANG_STOP_NAME = 0
-LANG_MESSAGE = 1
+LANGS = {"fr","nl"}
 
 
 class InvalidLineFilterException(Exception):
@@ -21,12 +19,15 @@ class STIBService:
         self._shapefile_service = ShapefileService(stib_api_client)
         self.api_client = stib_api_client
 
-    async def get_passages(self, stop_name, line_filters=None, max_passages=30, lang: tuple = None,
+    async def get_passages(self, stop_name, line_filters=None, max_passages=30, lang_stop_name=None, lang_message=None,
                            now=datetime.datetime.now()):
         stop_infos = await self._shapefile_service.get_stop_infos(stop_name)
 
-        if lang is None or lang == '':
-            lang = ('fr', 'fr')
+        if lang_message is None or lang_message not in LANGS:
+            lang_message = "fr"
+        if lang_stop_name is None or lang_stop_name not in LANGS:
+            lang_stop_name = "fr"
+
 
         atomic_stop_infos = stop_infos.get_atomic_stop_infos(line_filters)
         if len(atomic_stop_infos) < 1:
@@ -42,7 +43,7 @@ class STIBService:
                     break
                 message = ""
                 try:
-                    message = json_passage["message"][lang[LANG_MESSAGE]]
+                    message = json_passage["message"][lang_message]
                 except KeyError:
                     pass
                 try:
@@ -60,7 +61,7 @@ class STIBService:
                         is_only_end_of_service = False
                         passages.append(Passage(stop_id=point["pointId"],
                                                 lineId=json_passage["lineId"],
-                                                destination=json_passage["destination"][lang[LANG_STOP_NAME]],
+                                                destination=json_passage["destination"][lang_stop_name],
                                                 expectedArrivalTime=json_passage.get("expectedArrivalTime", None),
                                                 lineInfos=await self._shapefile_service.get_line_info(
                                                     json_passage["lineId"]),
@@ -73,9 +74,9 @@ class STIBService:
         if is_only_end_of_service or len(passages) == 0:
             raised_passages = []
             message = "Information from Schedule"
-            if lang[LANG_MESSAGE] == 'fr':
+            if lang_message == 'fr':
                 message = "Information venant du planning"
-            elif lang[LANG_MESSAGE] == 'nl':
+            elif lang_message == 'nl':
                 message = "Informatie uit de planning"
             for atomic in atomic_stop_infos:
                 next_passage = await self._shapefile_service.get_next_stop_passage(atomic.get_stop_id(), now)
